from parent_class import ParentPluralList
from kabbes_imessage import PhoneNumber

class PhoneNumbers( ParentPluralList ):

    def __init__( self ):
        ParentPluralList.__init__( self )

    def _add_PhoneNumber( self, new_PhoneNumber ):

        self._add( new_PhoneNumber )
        
    def make_PhoneNumber( self, *args, **kwargs ):

        new_PhoneNumber = PhoneNumber( *args, **kwargs )
        self._add_PhoneNumber( new_PhoneNumber )
        return new_PhoneNumber



import kabbes_imessage

###
message_body = input( 'Enter a message to send (enter to exit): ' )
Message_inst = kabbes_imessage.Message( message_body )

while True:
    phone_number = input( 'Enter a phone number to send this message to (enter to exit): ')
    if phone_number == '':
        break
    
    PhoneNumber_inst = kabbes_imessage.PhoneNumber( long_phone_number=phone_number )  
    if PhoneNumber_inst.valid:
        Message_inst.PhoneNumbers._add_PhoneNumber( PhoneNumber_inst )

Message_inst.send()



from parent_class import ParentClass
import kabbes_imessage
import os

class Message( ParentClass ):

    def __init__( self, message, PhoneNumbers_inst = None, phone_numbers = [], **kwargs ):

        ParentClass.__init__( self )

        self.message = message
        if type(PhoneNumbers_inst) == kabbes_imessage.PhoneNumbers:
            self.PhoneNumbers = PhoneNumbers_inst
        else:
            self.PhoneNumbers = kabbes_imessage.PhoneNumbers()

        for phone_number in phone_numbers:
            self.PhoneNumbers.make_PhoneNumber( long_phone_number = phone_number )            

        self.applescript_Path = kabbes_imessage.applescripts_Dir.join_Path( path = self.type + kabbes_imessage.applescript_extension )

    def print_one_line_atts( self, **kwargs ):

        return self._print_one_line_atts_helper( atts = [ 'type','PhoneNumbers' ], **kwargs )

    def print_imp_atts( self, **kwargs ):

        return self._print_imp_atts_helper( atts = ['message','PhoneNumbers'], **kwargs )

    def send( self, print_off: bool = True ):

        success = True

        if kabbes_imessage.ON_MAC:
            for PhoneNumber_inst in self.PhoneNumbers:

                if print_off:
                    print ('Sending ' + PhoneNumber_inst.medium + ' message ' + str(self.message) + ' to ' + str(PhoneNumber_inst) + '...' )

                applescript_Path = kabbes_imessage.mediums[ PhoneNumber_inst.medium ]

                try:
                    os.system( 'osascript {} {} "{}"'.format( applescript_Path.p, PhoneNumber_inst.formatted, self.message )  )
                except:
                    success = False
        else:
            print ('You are not on a Mac, cannot send iMessages')
            success = False

        return success



import re
from parent_class import ParentClass
import py_starter as ps

class PhoneNumber( ParentClass ):

    DEFAULT_ATT_VALUES = {
    'country_code': '1',
    'area_code': None,
    'phone_number': None,
    'digits': None,
    'formatted': None,
    'medium': 'iMessage'
    }

    def __init__( self, long_phone_number = '', **kwargs ):

        ParentClass.__init__( self )

        kwargs = ps.replace_default_kwargs( PhoneNumber.DEFAULT_ATT_VALUES, **kwargs )
        self.set_atts( kwargs )

        self.valid = False
        self.check_validity( long_phone_number )

    def __eq__( self, PhoneNumber_inst ):

        return self.digits == PhoneNumber_inst.digits

    def print_one_line_atts( self, **kwargs ):

        return self._print_one_line_atts_helper( atts = [ 'type','formatted' ], **kwargs )

    def print_imp_atts( self, **kwargs ):

        return self._print_imp_atts_helper( atts = ['country_code','area_code','phone_number','digits','formatted','valid','medium'], **kwargs )

    def check_validity( self, long_phone_number ):

        digits_only = self.filter_digits_from_str( long_phone_number )

        if len(digits_only) >= 10:
            self.valid = True

            self.phone_number = digits_only[ -7 :]
            self.area_code = digits_only[ -10:-7 ]

            if len(digits_only) > 10:
                self.country_code = digits_only[ : -10 ]

            self.digits = self.country_code + self.area_code + self.phone_number
            self.make_formatted()

    def make_formatted( self ):

        self.formatted = '+' + self.digits

    @staticmethod
    def filter_digits_from_str( number_str ):

        '''given a str, take only characters which are numbers, returns a string type'''

        return re.sub( '[^0-9]', '', str(number_str) )





import platform

ON_MAC = (platform.system() == 'Darwin')
if not ON_MAC:
    print ('kabbes_imessage Note: no messages will be able to send. You are not running this on a Macintosh system')

import dir_ops as do
import os

_Dir = do.Dir( os.path.abspath( __file__ ) ).ascend()   #Dir that contains the package 
_src_Dir = _Dir.ascend()                                  #src Dir that is one above
_repo_Dir = _src_Dir.ascend()                
_cwd_Dir = do.Dir( do.get_cwd() )

applescripts_Dir = _Dir.join_Dir( path = 'message_mediums' )
applescript_extension = '.applescript'

###
mediums_Paths = applescripts_Dir.list_contents_Paths( block_dirs=True )
mediums = {}
for medium_Path in mediums_Paths:
    mediums[ medium_Path.root ] = medium_Path


from .Message import Message
from .Messages import Messages
from .PhoneNumber import PhoneNumber
from .PhoneNumbers import PhoneNumbers




from parent_class import ParentPluralList
import kabbes_imessage

class Messages( ParentPluralList ):

    def __init__( self ):
        ParentPluralList.__init__( self, 'Messages' )

    def make_Message( self, *args, **kwargs ):

        new_Message = kabbes_imessage.Message( *args, **kwargs ) 
        self._add( new_Message )
        return new_Message

    def send( self, **kwargs ):
        
        success = True
        for Message_inst in self:
            if not Message_inst.send( **kwargs ):
                success = False
        
        return success


from setuptools import setup

if __name__ == '__main__':
    setup(
    package_data={'kabbes_imessage': 
        [ 
            'message_mediums/iMessage.applescript',
            'message_mediums/SMS.applescript'
        ]
        }
    )